<?php 

	
	/* The following formula is from
	 *   F. Langford-Smith (ed.),
	 *   "Radiotron Designer's Handbook", 4th edition
	 *   Wireless Press, 1952.
	 */
	
	function CoilQ( $a, $b, $f ) {
	  $Q = sqrt($f) / (0.069 / $a + 0.054 / $b);
	
	  return $Q;
	}
		
	
	/* IndCalc(a, b, n) - returns the inductance of a multiturn single layer circular coil
	 * a: coil radius [m] 
	 * b: coil length [m] 
	 * n: number of turns 
	 */
	function IndCalc( $a, $b, $n ) {
	
	  $u0 = 0.4000 * pi() * 1e-06;

	  $shape_ratio = 2 * $a / $b;
	
	  if ( $shape_ratio <= 1 ) {
		$l = $u0 * $n * $n * pi() * $a * $a * (f1($shape_ratio * $shape_ratio) - (4 /  (3 * pi())) * $shape_ratio) / $b;
	  } else {
		$l = $u0 * $n * $n * $a * ((log(4 * $shape_ratio) - 0.5) * f1(1 / ($shape_ratio * $shape_ratio)) + f2(1 / ($shape_ratio * $shape_ratio)));
	  }
	  return $l;
	}
	
	/* The following formulas are from
	 *   R. Lundin, 
	 *   "A Handbook Formula for the Inductance of a Single-Layer Circular Coil", 
	 *   Proc. IEEE, vol. 73, no. 9, pp. 1428-1429, Sep. 1985
	 */
	
	function f1( $x ) {
	  return (1 + $x * (0.383901 + 0.017108 * $x)) / (1 + 0.258952 * $x);
	}
	
	
	function f2( $x ) {
	  return ($x * (0.093842 + $x * (0.002029 - $x * 0.000801)));
	}
	
	function toPrec( $x ) {
	  return (3 - log($x) / log(10) );
	}


	if ( isset($_GET["d"]) ) {
	
		$a = $_GET["d"] / 2.0;
		$b = $_GET["b"] ;
		$n = $_GET["n"] ;
		$f = $_GET["f"]  * 1e06;
		
		if ($b!=0 && $a != 0 ) {
			$l = IndCalc( $a, $b, $n ) * 1e06 ; // Express in micro-Henries
			$Q = CoilQ( $a, $b, $f );
			
			$l = round( $l, 0 );
			$Q = round( $Q, 0 );
			$error = "";
		}
		else {
			$error = "There was an error in the inputs.";
		}
	}

?>



<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="en">

<!--  Version: Multiflex-3 Update-1 / Layout-1             -->
<!--  Date:    November 27, 2006                           -->
<!--  Author:  G. Wolfgang                                 -->
<!--  License: Fully open source without restrictions.     -->
<!--           Please keep footer credits with a link to   -->
<!--           G. Wolfgang (www.1-2-3-4.info). Thank you!  -->

<head>
  <meta http-equiv="content-type" content="text/html; charset=utf-8" />
  <meta http-equiv="cache-control" content="no-cache" />
  <meta http-equiv="expires" content="3600" />
  <meta name="revisit-after" content="2 days" />
  <meta name="robots" content="index,follow" />
  <meta name="publisher" content="Your publisher infos here ..." />
  <meta name="copyright" content="Your copyright infos here ..." />
  <meta name="author" content="Design: G. Wolfgang www.1-2-3-4.info / Author: Your author infos here ..." />
  <meta name="distribution" content="global" />
  <meta name="description" content="Your page description here ..." />
  <meta name="keywords" content="Your keywords, keywords, keywords, here ..." />
  <link rel="stylesheet" type="text/css" media="screen,projection,print" href="/css/layout1_setup.css" />
  <link rel="stylesheet" type="text/css" media="screen,projection,print" href="/css/layout1_text.css" />
  <link rel="icon" type="image/x-icon" href="/img/favicon.ico" />
  <title>Single Layer Inductor Calculation</title>
</head>

<!-- Global IE fix to avoid layout crash when single word size wider than column width -->
<!--[if IE]><style type="text/css"> body {word-wrap: break-word;}</style><![endif]-->

<body>
  <!-- Main Page Container -->
  <div class="page-container">

   <!-- For alternative headers START PASTE here -->

    <!-- A. HEADER -->      
    <div class="header">
      
      <!-- A.1 HEADER TOP -->
	  <?php include '../includes/HeaderTop.incl.html'; ?>
      
      <!-- A.2 HEADER BOTTOM -->
	  <?php include '../includes/HeaderBottom.incl.html'; ?>

      <!-- A.3 HEADER BREADCRUMBS -->

      <!-- Breadcrumbs -->
      <div class="header-breadcrumbs">
        <ul>
          <li><a href="/index.php">Home</a></li>
          <li>Single Layer Inductor Calculation</li>
        </ul>

        <!-- Search form -->                  
		<?php include '../includes/SearchForm.incl.php'; ?>
      </div>
    </div>
   <!-- For alternative headers END PASTE here -->

    <!-- B. MAIN -->
    <div class="main">
  
      <!-- B.1 MAIN CONTENT -->
      <div class="main-content">
        
        <!-- Pagetitle -->
        <h1 class="pagetitle">Single Layer Inductor Calculation</h1>


		<h2>Single-layer Coil Inductance and "Q"</h2>

			<p>
				I've been playing with some Loop Antennas and have ideas for some small receiving
				loops. These fit the model of a single-layer inductor, or solenoid, type of inductance.
			</p>
			
			<form name="calcInductor" action="singlelayerinductor.php" method="get">
			
			<?php
			/*
			<span style="float: right;">
			<img src="coil1.gif" alt="Coil dimensions" />
			</span>
			*/
			?>
			
			<table >
			<tr><th>Coil diameter,   d </th><td><input type="text" name="d" id="d" size="10" maxlength="10" value=<?php if ( isset($_GET["d"]) ) { echo '"' . $_GET["d"] . '"'; } else { echo '"0.20955"'; }  ?>/> m </td></tr>
			<tr><th>Coil length,     l</th><td> <input type="text" name="b" id="b" size="10" maxlength="10" value=<?php if ( isset($_GET["b"]) ) { echo '"' . $_GET["b"] . '"'; } else { echo '"0.0254"'; }  ?>  /> m </td></tr>
			<tr><th>Number of turns, n </th><td><input type="text" name="n" id="n" size="10" maxlength="10" value=<?php if ( isset($_GET["n"]) ) { echo '"' . $_GET["n"] . '"'; } else { echo '"30"'; }  ?> /> </td></tr>
			<tr><th>&nbsp;</th><td>&nbsp;</td></tr>
			<tr><th>Frequency, (MHz)  - used only for computing coil "Q"</th><td><input type="text" name="f" id="f" size="10" maxlength="10" value=<?php if ( isset($_GET["n"]) ) { echo '"' . $_GET["n"] . '"'; } else { echo '"1.000"'; }  ?> /></td></tr>
			</table>
			
			<input type="submit" value="Calculate" /> 
			
			<h2>Calculated Inductance, "Q"</h2>
			
			<?php 
				if ($error == "") {
					?>
					<table >
					<tr><th>Inductance</th><td>L = <?php if ( isset($_GET["d"]) ) { echo $l . " &#181;H"; } ?> </td></tr>
					<tr><th>Inductor "Q"</th><td>"Q" = <?php if ( isset($_GET["d"]) ) { echo $Q . " at " . $f / 1000000 . " Mhz."; } ?></td></tr>
					</table>
					<?php
				}
				else {
					echo "<table><tr><th>" . $error . "</th></tr></table>";
				}			
			?>		
			
			</form>


		<p>For more technical data, see: F.E. Terman, "<strong>Radio Engineers' Handbook</strong>," London, McGraw-Hill, 1st ed., Sep. 1950.</p>
 

      </div>
    </div>
      
    <!-- C. FOOTER AREA -->      
	<?php include '../includes/Footer.incl.html'; ?>
	
  </div> 
  
</body>
</html>